@@ -16,10 +16,11 @@
 
 import sys
 import re
-import xml.dom.minidom
-from calculate.lib.cl_template import TemplateFormat
-
-from calculate.lib.cl_lang import setLocalTranslate
+# import xml.dom.minidom
+from lxml import etree
+from ..cl_template import TemplateFormat
+from ..cl_xml import firstChild
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
@@ -37,8 +38,8 @@ class patch(TemplateFormat):
     def prepare(self):
         # Создаем XML документ
         self.doc = self.textToXML()
-        if self.doc:
-            self.rootNode = self.doc.documentElement
+        if self.doc is not None:
+            self.rootNode = self.doc.getroottree().getroot()
         self.reFlags = 0
 
     def textToXML(self):
@@ -50,7 +51,8 @@ class patch(TemplateFormat):
         text = ('<?xml version="1.0" encoding="UTF-8"?>\n<patch>%s</patch>'
                 % self.text)
         try:
-            self.doc = xml.dom.minidom.parseString(text)
+            # self.doc = xml.dom.minidom.parseString(text)
+            self.doc = etree.XML(bytes(bytearray(text, encoding='utf-8')))
         except Exception:
             return False
         return self.doc
@@ -63,7 +65,7 @@ class patch(TemplateFormat):
 
     def processingFile(self, textConfigFile, rootPath=None, nameFile=None):
         """Обработка конфигурационного файла"""
-        if not self.doc:
+        if self.doc is None:
             self.setError(_("Failed to convert the text template to XML"))
             return False
         retTextConfigFile = textConfigFile
@@ -71,54 +73,54 @@ class patch(TemplateFormat):
         dataList = []
         tagsIndex = 0
         regex = False
-        for node in self.rootNode.childNodes:
-            if node.nodeType == node.ELEMENT_NODE:
-                if not node.tagName == tags[tagsIndex]:
-                    self.setError(_("Incorrect template text"))
-                    return False
-                if tagsIndex == 1:
-                    tagsIndex = 0
+        for node in list(self.rootNode):
+            # if node.nodeType == node.ELEMENT_NODE:
+            if not node.tag == tags[tagsIndex]:
+                self.setError(_("Incorrect template text"))
+                return False
+            if tagsIndex == 1:
+                tagsIndex = 0
+            else:
+                tagsIndex += 1
+            # регулярное выражение
+            if node.tag == "reg":
+                if firstChild(node) is not None:
+                    reText = firstChild(node).text
+                    if reText is None:
+                        textNode = node.toxml()
+                        self.setError(
+                            _("Incorrect template text") + ": \n" +
+                            "%s" % textNode)
+                        return False
                 else:
-                    tagsIndex += 1
-                # регулярное выражение
-                if node.tagName == "reg":
-                    if node.firstChild:
-                        reText = node.firstChild.nodeValue
-                        if reText is None:
-                            textNode = node.toxml().encode("UTF8")
-                            self.setError(
-                                _("Incorrect template text") + ": \n" +
-                                "%s" % textNode)
-                            return False
-                    else:
+                    self.setError(
+                        _("Incorrect text of template '<reg></reg>'"))
+                    return False
+                if not reText.strip():
+                    self.setError(
+                        _("Incorrect text of template '<reg>%s</reg>'")
+                        % reText)
+                    return False
+                try:
+                    regex = re.compile(reText, self.reFlags)
+                except re.error:
+                    self.setError(
+                        _("Incorrect text of template '<reg>%s</reg>'")
+                        % reText)
+                    return False
+            elif node.tag == "text" and regex:
+                if firstChild(node) is not None:
+                    text = firstChild(node).text
+                    if text is None:
+                        textNode = node.toxml()
                         self.setError(
-                            _("Incorrect text of template '<reg></reg>'"))
+                            _("Incorrect template text") + ": \n" +
+                            "%s" % textNode)
                         return False
-                    if not reText.strip():
-                        self.setError(
-                            _("Incorrect text of template '<reg>%s</reg>'")
-                            % reText.encode("UTF8"))
-                        return False
-                    try:
-                        regex = re.compile(reText, self.reFlags)
-                    except re.error:
-                        self.setError(
-                            _("Incorrect text of template '<reg>%s</reg>'").decode('utf-8')
-                            % reText.encode("UTF8"))
-                        return False
-                elif node.tagName == "text" and regex:
-                    if node.firstChild:
-                        text = node.firstChild.nodeValue
-                        if text is None:
-                            textNode = node.toxml().encode("UTF8")
-                            self.setError(
-                                _("Incorrect template text") + ": \n" +
-                                "%s" % textNode)
-                            return False
-                    else:
-                        text = ""
-                    dataList.append((regex, text.encode('utf-8')))
-                    regex = False
+                else:
+                    text = ""
+                dataList.append((regex, text))
+                regex = False
         for regex, text in dataList:
             # Замены в тексте конфигурационного файла
             retTextConfigFile = regex.sub(text, retTextConfigFile)
